Muscle.LAST.add_classpath (File.dirname(__FILE__) + "/dist/laplace.jar")

# configure cxa properties
cxa = Cxa.LAST

# declare kernels
cxa.add_kernel('west1', 'laplace.TemperatureKernel') # South side
cxa.add_kernel('west2', 'laplace.TemperatureKernel') # North side
cxa.add_kernel('east', 'laplace.TemperatureKernel')
cxa.add_kernel('combine', 'laplace.mapper.CombineDoubleMapper')
cxa.add_kernel('divide', 'laplace.mapper.DivideDoubleMapper')

cxa.env["default_dt"] = 1 # all models take the same timestep, of 1 second
cxa.env["max_timesteps"] = 5000 # total number of seconds

# Submodel geometry
cxa.env["nx"] = 100
cxa.env["ny"] = 25
cxa.env["dx"] = 4

cxa.env["east:ny"] = cxa.env["ny"]*2
cxa.env["east:originx"] = cxa.env["nx"]
cxa.env["east:name"] = "East"
cxa.env["east:remoteWest"] = true


cxa.env["west1:name"] = "West-South"
cxa.env["west1:originy"] = cxa.env["ny"]
cxa.env["west1:remoteEast"] = true
cxa.env["west1:remoteNorth"] = true

cxa.env["west2:name"] = "West-North"
cxa.env["west2:remoteEast"] = true
cxa.env["west2:remoteSouth"] = true

cxa.env["divide:size1"] = cxa.env["ny"]
cxa.env["divide:size2"] = cxa.env["ny"]

# configure connection scheme
cs = cxa.cs

# East to west
cs.attach('east' => 'divide') {
	tie('westBoundary', 'in')
}
cs.attach('divide' => 'west1') {
	tie('out1', 'remoteEast')
}
cs.attach('divide' => 'west2') {
	tie('out2', 'remoteEast')
}

# West to east
cs.attach('west1' => 'combine') {
	tie('eastBoundary', 'in1')
}
cs.attach('west2' => 'combine') {
	tie('eastBoundary', 'in2')
}
cs.attach('combine' => 'east') {
	tie('out', 'remoteWest')
}

# North to south and back
cs.attach('west2' => 'west1') {
	tie('southBoundary', 'remoteNorth')
}
cs.attach('west1' => 'west2') {
	tie('northBoundary', 'remoteSouth')
}

