Muscle.LAST.add_classpath (File.dirname(__FILE__) + "/dist/laplace.jar")

# configure cxa properties
cxa = Cxa.LAST

# declare kernels
cxa.add_kernel('west', 'laplace.TemperatureKernel')
cxa.add_kernel('east', 'laplace.TemperatureKernel')
cxa.add_terminal('farWestSource', 'laplace.terminal.DoubleArraySource')
cxa.add_terminal('farWestNullSink', 'muscle.core.conduit.terminal.NullSink')

cxa.env["default_dt"] = 1 # all models take the same timestep, of 1 second
cxa.env["max_timesteps"] = 5000 # total number of seconds

# Submodel geometry
cxa.env["nx"] = 100
cxa.env["ny"] = 50
cxa.env["dx"] = 4

# Other submodel properties
cxa.env["west:name"] = "West"
cxa.env["west:remoteEast"] = true # east side will be computed remotely
cxa.env["west:remoteWest"] = true

cxa.env["east:name"] = "East"
cxa.env["east:remoteWest"] = true # west side will be computed remotely
cxa.env["east:originx"] = cxa.env["nx"] # place window nx steps to the right

cxa.env["farWestSource:value"] = 1.0 # set western border to 1
cxa.env["farWestSource:size"] = cxa.env["ny"] # number of elements to generate

# configure connection scheme
cs = cxa.cs

# West to east and back
cs.attach('west' => 'east') {
	tie('eastBoundary', 'remoteWest')
}
cs.attach('east' => 'west') {
	tie('westBoundary', 'remoteEast')
}

# Tie west boundary to a source and a sink
cs.attach('farWestSource' => 'west') {
    tie('remoteWest')
}
cs.attach('west' => 'farWestNullSink') {
    tie('westBoundary')
}

