package laplace.filter;

import muscle.core.conduit.filter.AbstractFilter;
import muscle.core.model.Observation;
import muscle.util.data.SerializableDatatype;

public class IncreaseFilter extends AbstractFilter<double[],double[]> {
    private final double increment;

    public IncreaseFilter(double increment) {
        this.increment = increment;
    }

    public void apply(Observation<double[]> obs) {
        // Do not modify the original data of the submodel, so make a private copy and use the resulting data
        // If you supply the datatype in advance (DOUBLE_ARR), the copy operation will be faster.
        Observation<double[]> output = obs.privateCopy(SerializableDatatype.DOUBLE_ARR);
        double[] data = output.getData();

		// Reduce negative numbers, increase positive numbers, within the range [-1, 1]
        for (int i = 0; i < data.length; i++) {
            if (data[i] < 0) data[i] = Math.max(-1.0, data[i] - increment);
            else             data[i] = Math.min(1.0, data[i] + increment);
        }

        // Create a new observation for the data
        put(output);
    }
}
