package laplace.graphics;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import javax.swing.JFrame;
import javax.swing.JPanel;

/**
 *
 * @author Joris Borgdorff
 */
public class GraphicsPanel extends JPanel {
	private static final long serialVersionUID = 1L;
	private final int nx, ny, dx;
	private double[][] data = null;
	
	public GraphicsPanel(int nx, int ny, int dx) {
		this.dx = dx;
		this.nx = nx;
		this.ny = ny;
		setPreferredSize(new Dimension(nx * dx, ny * dx));
	}
	
	public void show(String name, int xdiff, int ydiff) {
		JFrame frame = new JFrame(name);
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.add(this);

		frame.setLocation((int) frame.getLocation().getX() + xdiff, (int) frame.getLocation().getY() + ydiff);

		frame.pack();
		frame.setVisible(true);
	}
	
	public synchronized void paintAndWait(double[][] newData) {
		synchronized (this) {
			while (data != null) {
				try {
					wait();
				} catch (InterruptedException e) {
					throw new RuntimeException(e);
				}
			}
			data = newData;
		}
		repaint();
	}
	
	protected void paintComponent(Graphics gg) {
		synchronized (this) {
			if (data == null) return;
		}
		super.paintComponent(gg);
		Graphics2D g = (Graphics2D) gg;
		// fill with initial conditions
		for (int x = 0; x < nx; x++) {
			for (int y = 0; y < ny; y++) {
				g.setColor(getColor(data[x][y]));
				g.fillRect(x * dx, (ny - 1) * dx - 1 * y * dx, dx, dx);
			}
		}
		synchronized (this) {
			data = null;
			notify();
		}
	}
	
	/**
	 * create a colour gradient from blue to red from the input values from -1..1
	 */
	private static Color getColor(double rawVal) {
		// first we apply val to our colour range, which is from 0...4*256
        double rawPositive = rawVal == 1.0 ? rawPositive = 1.999 : rawVal + 1.0; // -1..1 -> 0...2
		int val = (int)(rawPositive * 512.0) % 256; // 0...2 -> 0...4*256 -> 0...256
		int regime = (int) (rawPositive * 2.0);  // 0...2 -> 0..3

        switch (regime) {
            case 0: // -1 .. -0.5
			    return new Color(0, val, 255); // Blue to aqua
            case 1: // -0.5 .. 0
			    return new Color(0, 255, 255 - val); // Aqua to green
            case 2: // 0 .. 0.5
			    return new Color(val, 255, 0); // Green to yellow
            case 3: // 0 .. 1.0
			    return new Color(255, 255 - val, 0); // Yellow to red
            default:
                throw new IllegalArgumentException("Value " + rawVal + " out of range -1..1 of color calculation");
        }
	}
}
