package laplace.model;

/**
 * boundary condition which applies to the main area of the grid<br>
 * calculates new value bases on the four neighbour values
 */
public class AreaFunction extends BoundaryCondition {
	private double[][] data;

	public AreaFunction(int newNx, int newNy) {
		super(Direction.Area, newNx, newNy);
	}

	public void updateData(double[][] data) {
		this.data = data;
	}
	
	// calc new value based on the neighbours
	public double get(int x, int y, int step) {
		double n = data[x][y + 1];
		double ne = data[x + 1][y + 1];
		double e = data[x + 1][y];
		double se = data[x + 1][y - 1];
		double s = data[x][y - 1];
		double sw = data[x - 1][y - 1];
		double w = data[x - 1][y];
		double nw = data[x - 1][y + 1];
		return (n + ne + e + se + s + sw + w + nw) / 8.0;
	}

}
