package laplace.model;

/**
 * interface for boundary conditions
 */
public class BoundaryCondition {
	protected final Direction direction;
	protected final int ny;
	protected final int nx;
	
	public enum Direction {
		East, West, North, South, Any, Area;
	}
	
	public BoundaryCondition(Direction direction, int nx, int ny) {
		this.direction = direction;
		this.nx = nx;
		this.ny = ny;
	}
	
	public boolean applies(int x, int y) {
		switch (direction) {
			case East:
				return x == nx - 1;
			case West:
				return x == 0;
			case North:
				return y == ny - 1;
			case South:
				return y == 0;
			case Area:
				return x > 0 && x < nx - 1 && y > 0 && y < ny - 1;
			default:
				return true;
		}
	}

	public double get(int x, int y, int step) {
		return 0d;
	}
}
