package laplace.model;

import laplace.model.BoundaryCondition.Direction;

/**
 * custom boundary condition which is using a ghost column to
 * synchronize data with another submodel
 */
public class CommunicationBoundary extends BoundaryCondition {
	private double[] localSlice;
	private double[][] data;
    private boolean horizontal;
	
	public CommunicationBoundary(Direction dir, int newNx, int newNy, double[][] data) {
		super(dir, newNx, newNy);
		this.data = data;
        this.horizontal = (dir == Direction.East || dir == Direction.West);

		// init local slice
		localSlice = new double[horizontal ? ny : nx];
	}

    /**
     * Update the data to compute the next iteration from, including
     * the slice from the remote site
     */
	public void updateData(double[][] data, double[] slice) {
		this.data = data;
		int extremal;
		switch (direction) {
			case North:
				extremal = ny - 1;
				break;
			case East:
				extremal = nx - 1;
				break;
			default:
				extremal = 0;
				break;
		}
		if (horizontal)
			for (int y = 0; y < ny; y++)
				data[extremal][y] = slice[y];
		else
			for (int x = 0; x < nx; x++)
				data[x][extremal] = slice[x];
	}
	
    /**
     * Get the boundary that could be communicated to the remote site.
     */
	public double[] getLocalBoundary(double[][] data) {
		this.data = data;
		int extremal;
		switch (direction) {
			case North:
				extremal = ny - 2;
				break;
			case East:
				extremal = nx - 2;
				break;
			default:
				extremal = 1;
				break;
		}
		if (horizontal)
			for (int y = 0; y < ny; y++)
				localSlice[y] = data[extremal][y];
		else
			for (int x = 0; x < nx; x++)
				localSlice[x] = data[x][extremal];

		return localSlice;
	}
	
	// synchronize remote column with their corresponding original data
	// calc new boundary value based on the neighbours
	public double get(int x, int y, int step) {
		return data[x][y];
	}
}
